<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "无法从应用商店载入列表",
"Authentication error" => "认证错误",
"Group already exists" => "已存在该组",
"Unable to add group" => "无法添加组",
"Could not enable app. " => "无法开启App",
"Email saved" => "电子邮件已保存",
"Invalid email" => "无效的电子邮件",
"Unable to delete group" => "无法删除组",
"Unable to delete user" => "无法删除用户",
"Language changed" => "语言已修改",
"Invalid request" => "非法请求",
"Admins can't remove themself from the admin group" => "管理员不能将自己移出管理组。",
"Unable to add user to group %s" => "无法把用户添加到组 %s",
"Unable to remove user from group %s" => "无法从组%s中移除用户",
"Disable" => "禁用",
"Enable" => "启用",
"Error" => "错误",
"Saving..." => "正在保存",
"deleted" => "已经删除",
"undo" => "撤销",
"Groups" => "组",
"Group Admin" => "组管理员",
"Delete" => "删除",
"__language_name__" => "简体中文",
"Security Warning" => "安全警告",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "您的数据文件夹和文件可由互联网访问。OwnCloud提供的.htaccess文件未生效。我们强烈建议您配置服务器，以使数据文件夹不可被访问，或者将数据文件夹移到web服务器根目录以外。",
"More" => "更多",
"Version" => "版本",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "由<a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud社区</a>开发，  <a href=\"https://github.com/owncloud\" target=\"_blank\">源代码</a>在<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>许可证下发布。",
"Add your App" => "添加应用",
"More Apps" => "更多应用",
"Select an App" => "选择一个应用",
"See application page at apps.owncloud.com" => "查看在 app.owncloud.com 的应用程序页面",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-核准： <span class=\"author\"></span>",
"Update" => "更新",
"User Documentation" => "用户文档",
"Administrator Documentation" => "管理员文档",
"Online Documentation" => "在线文档",
"Forum" => "论坛",
"Bugtracker" => "问题跟踪器",
"Commercial Support" => "商业支持",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "你已使用 <strong>%s</strong>，有效空间 <strong>%s</strong>",
"Get the apps to sync your files" => "安装应用进行文件同步",
"Password" => "密码",
"Your password was changed" => "密码已修改",
"Unable to change your password" => "无法修改密码",
"Current password" => "当前密码",
"New password" => "新密码",
"Change password" => "修改密码",
"Email" => "电子邮件",
"Your email address" => "您的电子邮件",
"Fill in an email address to enable password recovery" => "填写电子邮件地址以启用密码恢复功能",
"Language" => "语言",
"Help translate" => "帮助翻译",
"WebDAV" => "WebDAV",
"Use this address to connect to your ownCloud in your file manager" => "用该地址来连接文件管理器中的 ownCloud",
"Create" => "创建",
"Default Storage" => "默认存储",
"Unlimited" => "无限",
"Other" => "其它",
"Storage" => "存储",
"Default" => "默认"
);
